@@ -21,9 +21,8 @@ class PageRouter extends \PKP\core\PKPPageRouter
     /**
      * get the cacheable pages
      *
-     * @return array
      */
-    public function getCacheablePages()
+    public function getCacheablePages(): array
     {
         return ['about', 'announcement', 'help', 'index', 'information', 'issue', ''];
     }
