@@ -12,17 +12,14 @@
  * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @ingroup pages_catalog
+ *
  * @brief Handle requests for the public catalog view.
  *
  */
 
 switch ($op) {
-	case 'category':
-	case 'fullSize':
-	case 'thumbnail':
-		define('HANDLER_CLASS', 'PKPCatalogHandler');
-		import('lib.pkp.pages.catalog.PKPCatalogHandler');
-		break;
+    case 'category':
+    case 'fullSize':
+    case 'thumbnail':
+        return new PKP\pages\catalog\PKPCatalogHandler();
 }
-
-
